@@ -6,3 +6,7 @@ from .net import (
 from .shell import shell, bash, pipe
 from .ssh import SSH, ParamSSH
 from .config import get_app_config
+from .tracer import Tracer, trace, set_tracer
+from .fuzzy import fuzzy_select
+from .dico import Dico
+from .func import singleton
