@@ -16,8 +16,13 @@ class Fernet:
         key = urlsafe_b64encode(h.digest())
         return key
 
-    def encrypt(self, data):
-        return self.fernet.encrypt(data.encode())
+    def encrypt(self, data, text=True):
+        if text:
+            data = data.encode()
+        return self.fernet.encrypt(data)
 
-    def decrypt(self, data):
-        return self.fernet.decrypt(data).decode()
+    def decrypt(self, data, text=True):
+        data = self.fernet.decrypt(data)
+        if text:
+            data = data.decode()
+        return data
