@@ -1,4 +1,5 @@
 from functools import partial
+import shlex
 from subprocess import (
     CalledProcessError,
     PIPE,
@@ -38,10 +39,11 @@ def shell(script, shell, color=False):
 def pipe(*cmds):
     prev = None
     for cmd in cmds:
+        cmd = shlex.split(cmd)
         if prev:
-            proc = Popen(cmd.split(), stdin=prev.stdout, stdout=PIPE)
+            proc = Popen(cmd, stdin=prev.stdout, stdout=PIPE)
         else:
-            proc = Popen(cmd.split(), stdout=PIPE)
+            proc = Popen(cmd, stdout=PIPE)
         prev = proc
 
     for line in proc.stdout.read().decode().strip().split('\n'):
